meta_package_manager.tests.test_cli module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.tests.test_cli module

class `meta_package_manager.tests.test_cli.` `TestCLI`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_bare_call`()
  `test_main_help`()
  `test_version`()
  `test_verbosity`()

class `meta_package_manager.tests.test_cli.` `TestCLIManagers`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_main_help`()
  `test_verbosity`()
  `test_simple_call`()
  `test_simple_table_rendering`()
  `test_plain_table_rendering`()
  `test_json_output`()
  `test_json_debug_output`()
  `test_sub_manager_scope`()

class `meta_package_manager.tests.test_cli.` `TestCLISync`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_main_help`()
  `test_verbosity`()
  `test_simple_call`()
  `test_sub_manager_scope`()

class `meta_package_manager.tests.test_cli.` `TestCLIList`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_main_help`()
  `test_verbosity`()
  `test_simple_call`()
  `test_sub_manager_scope`()

class `meta_package_manager.tests.test_cli.` `TestCLIOutdated`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_main_help`()
  `test_verbosity`()
  `test_simple_call`()
  `test_simple_table_rendering`()
  `test_plain_table_rendering`()
  `test_json_output`()
  `test_json_debug_output`()
  `test_sub_manager_scope`()
  `test_cli_format_plain`()
  `test_cli_format_fragments`()
  `test_cli_format_bitbar`()

class `meta_package_manager.tests.test_cli.` `TestCLIUpgrade`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.

  `test_main_help`()
  `test_verbosity`()
  `test_simple_call`()
  `test_sub_manager_scope`()
  `test_full_upgrade`(*args, **kwargs)